pyhydrotel
===================================================================

The pyhydrotel package includes functions for extracting sites, measurement types, and time series data from a hydrotel system installed on an MSSQL server.

Installation
------------
pyhydrotel can be installed via pip or conda::

  pip install pyhydrotel

or::

  conda install -c mullenkamp pyhydrotel
